@@ -24,6 +24,7 @@
 #include <string>
 #include <sstream>
 #include <cmath>
+#include <vector>
 #include <fors_bias_impl.h>
 
 #include <fors_stack.h>
@@ -31,6 +32,7 @@
 #include <fors_tools.h>
 #include <fors_dfs.h>
 #include <fors_utils.h>
+#include <fors_bpm.h>
 #include <moses.h>
 #include "fors_ccd_config.h"
 #include "mosca_image.h"
@@ -74,7 +76,8 @@ write_qc(cpl_propertylist *qc,
          const fors_image_list *bias,
          const fors_image *master_bias,
          const stack_method *sm,
-         const mosca::ccd_config ccd_config);
+         const mosca::ccd_config ccd_config,
+         bool  perform_preoverscan);
 /**
  * @brief    Define recipe parameters
  * @param    parameters     parameter list to fill
@@ -233,21 +236,42 @@ void fors_bias(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Load bias */
     fors_image_list * bias_raw = 
             fors_image_load_list(bias_frames);
+    fors_image * bias_first = fors_image_list_first(bias_raw);
     assure( !cpl_error_get_code(), return, "Could not load bias images");
 
     /* Compute RON */
     fors_bias_compute_ron(bias_raw, bias_ccd_config);
     
+    /* Check if overscan is present in the raw images */
+    bool perform_preoverscan = !fors_is_preoverscan_empty(bias_ccd_config);
+
     /* Create variances map */
-    fors_image_variance_from_detmodel(bias_raw, bias_ccd_config);
+    std::vector<double> overscan_levels;
+    if(perform_preoverscan)
+        overscan_levels = fors_get_bias_levels_from_overscan(bias_first,
+                                                             bias_ccd_config);
+    else
+        overscan_levels = fors_get_bias_levels_from_mbias(bias_first,
+                                                          bias_ccd_config);
+
+    fors_image_variance_from_detmodel(bias_raw, bias_ccd_config, 
+                                      overscan_levels);
     assure( !cpl_error_get_code(), return, "Cannot create variances map");
     
     /* Subtract overscan */
-    bias = fors_subtract_prescan(bias_raw, bias_ccd_config);
+    if(perform_preoverscan)
+        bias = fors_subtract_prescan(bias_raw, bias_ccd_config);
+    else 
+    {
+        bias = fors_image_list_duplicate(bias_raw, fors_image_duplicate);
+        //The rest of the recipe assumes that the images carry a bpm.
+        fors_bpm_image_list_make_explicit(bias); 
+    }
     assure( !cpl_error_get_code(), return, "Cannot subtract pre/overscan");
 
     /* Trimm pre/overscan */
-    fors_trimm_preoverscan(bias, bias_ccd_config);
+    if(perform_preoverscan)
+        fors_trimm_preoverscan(bias, bias_ccd_config);
     fors_image_list_delete(&bias_raw, fors_image_delete);
     assure( !cpl_error_get_code(), return, "Cannot trimm pre/overscan");
 
@@ -258,7 +282,7 @@ void fors_bias(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* QC */
     write_qc(qc, setting,
              cpl_frameset_get_position(bias_frames, 0),
-             bias, master_bias, sm, bias_ccd_config);
+             bias, master_bias, sm, bias_ccd_config, perform_preoverscan);
 
     /* Save product */
     fors_dfs_save_image_err(frames, master_bias, MASTER_BIAS,
@@ -320,6 +344,7 @@ fors_bias_stack(const fors_image_list *images, const stack_method *sm)
     images_hdrl = fors_image_list_to_hdrl(images);
     hdrl_imagelist_collapse(images_hdrl, stackmethod_par ,&master_bias_hdrl, 
                             &contrib);
+    assure( !cpl_error_get_code(), return NULL, "Collapsing of bias failed ");
     cpl_image_delete(contrib);
     master_bias = fors_image_from_hdrl(master_bias_hdrl);
     
@@ -373,7 +398,8 @@ write_qc(cpl_propertylist *qc,
          const fors_image_list *bias,
          const fors_image *master_bias,
          const stack_method *sm,
-         const mosca::ccd_config ccd_config)
+         const mosca::ccd_config ccd_config,
+         bool  perform_preoverscan)
 {
     const fors_image *first_raw  = fors_image_list_first_const(bias);
     const fors_image *second_raw = fors_image_list_next_const(bias);
@@ -542,6 +568,12 @@ write_qc(cpl_propertylist *qc,
     }
 
     
+    cpl_propertylist_update_bool(qc, "ESO QC BIAS OVSC_SUB", 
+                                     perform_preoverscan); 
+    cpl_propertylist_set_comment(qc, "ESO QC BIAS OVSC_SUB", 
+                                 "Whether overscan has been subtracted");
+    assure( !cpl_error_get_code(), return, 
+            "Could not update keyword QC BIAS OVSC_SUB");
 
     cleanup;
     return;
