@@ -95,3 +95,48 @@ cpl_image * fors_bpm_create_combined_bpm
     
     return combined_bpm;
 }
+
+
+/**
+ * This function will ensure that each of the input images in the list has
+ * a explicit bpm. If the bpm were NULL, one is created with all the pixels
+ * set to valid 
+ * @param ima_list  The input image list
+ */
+void fors_bpm_image_list_make_explicit(fors_image_list * ima_list)
+{
+    int nima = fors_image_list_size(ima_list);
+
+    const fors_image * target_ima = fors_image_list_first_const(ima_list);
+    for(int ima = 0; ima < nima; ++ima)
+    {
+        fors_bpm_image_make_explicit(target_ima);
+        target_ima = fors_image_list_next_const(ima_list);
+    }
+
+    return;
+}
+
+/**
+ * This function will ensure that the input images has
+ * a explicit bpm. If the bpm were NULL, one is created with all the pixels
+ * set to valid 
+ * @param ima_list  The input image list
+ */
+void fors_bpm_image_make_explicit(const fors_image * ima)
+{
+    cpl_size dim_x = cpl_image_get_size_x(ima->data);
+    cpl_size dim_y = cpl_image_get_size_y(ima->data);
+    if(cpl_image_get_bpm_const(ima->data) == NULL)
+    {
+        cpl_mask * this_mask = cpl_mask_new(dim_x, dim_y);
+        cpl_image_set_bpm(ima->data, this_mask);
+    }
+    if(cpl_image_get_bpm_const(ima->variance) == NULL)
+    {
+        cpl_mask * this_mask = cpl_mask_new(dim_x, dim_y);
+        cpl_image_set_bpm(ima->variance, this_mask);
+    }
+
+    return;
+}
