@@ -144,7 +144,7 @@ void fors_dark(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Find calibration */
     master_bias_frame = fors_frameset_extract(frames, MASTER_BIAS);
     assure( cpl_frameset_get_size(master_bias_frame) == 1, return, 
-            "One %s required. %"CPL_SIZE_FORMAT" found", 
+            "One %s required. %" CPL_SIZE_FORMAT " found", 
             MASTER_BIAS, cpl_frameset_get_size(master_bias_frame));
 
     /* Update RON estimation from bias */
@@ -211,6 +211,9 @@ void fors_dark(cpl_frameset *frames, const cpl_parameterlist *parameters)
     fors_write_images_mean_stddev_in_propertylist(darks_raw, master_dark_header,
                                     "ESO QC DARK RAW STDEV MEAN");
 
+    fors_write_num_bad_pixels_propertylist(darks_raw, master_dark_header,
+                                    "ESO QC DARK RAW NBADPX");
+
     fors_image_list_delete(&darks_raw, fors_image_delete);
 
     /* Subtract master bias */
@@ -232,8 +235,6 @@ void fors_dark(cpl_frameset *frames, const cpl_parameterlist *parameters)
                                    "ESO QC DARK MEDIAN");
    fors_write_stdev_in_propertylist(master_dark, master_dark_header,
                                    "ESO QC DARK STDEV");
-   fors_write_num_bad_pixels_propertylist(master_dark, master_dark_header,
-                                   "ESO QC DARK NBADPX");
 
    /* Save product */
    fors_dfs_save_image_err(frames, master_dark, MASTER_DARK,
