@@ -94,7 +94,7 @@ static const cpl_frame* get_next_const_and_advance(cpl_frameset_iterator* it)
 /*----------------------------------------------------------------------------*/
 char *dfs_generate_filename(const char *category)
 {
-    char *filename = cpl_calloc(strlen(category) + 6, sizeof(char));
+    char *filename = (char*)cpl_calloc(strlen(category) + 6, sizeof(char));
 
     strlower(strcpy(filename, category));
     strcat(filename, ".fits");
@@ -342,10 +342,11 @@ fors_dfs_set_groups(cpl_frameset * set)
                      strcmp(tag, "STD_FLUX_TABLE"               ) == 0 ||
                      strcmp(tag, "SPECPHOT_TABLE"               ) == 0 ||
                      strcmp(tag, PHOT_TABLE                     ) == 0 ||
-            		 strcmp(tag, PHOT_COEFF_TABLE               ) == 0 ||
-            		 strcmp(tag, STATIC_PHOT_COEFF_TABLE        ) == 0 ||
-            		 strcmp(tag, EXTINCTION_PER_NIGHT           ) == 0) {
-                cpl_frame_set_group(f, CPL_FRAME_GROUP_CALIB);
+                     strcmp(tag, PHOT_COEFF_TABLE               ) == 0 ||
+                     strcmp(tag, EXTINCTION_PER_NIGHT           ) == 0 ||
+                     strcmp(tag, STATIC_PHOT_COEFF_TABLE        ) == 0 ||
+                     strcmp(tag, DETECTOR_ILLUMINATED_REGION    ) == 0) {
+                     cpl_frame_set_group(f, CPL_FRAME_GROUP_CALIB);
             }
             else {
                 cpl_msg_warning(cpl_func, "Unrecognized frame tag: '%s'",
@@ -1044,7 +1045,7 @@ dfs_save(cpl_frameset *frameset, const void *object, fors_type type,
         }       
     }
 
-    filename = cpl_calloc(strlen(category) + 6, sizeof(char));
+    filename = (char*)cpl_calloc(strlen(category) + 6, sizeof(char));
 
     strlower(strcpy(filename, category));
     strcat(filename, ".fits");
@@ -1214,7 +1215,7 @@ fors_dfs_save_image_mask(cpl_frameset *frameset, const cpl_image *image,
     cpl_propertylist_append_string(extension_header, 
                                    "EXTNAME", "IMAGE.BPM");
 
-    filename = cpl_calloc(strlen(category) + 6, sizeof(char));
+    filename = (char*)cpl_calloc(strlen(category) + 6, sizeof(char));
 
     strlower(strcpy(filename, category));
     strcat(filename, ".fits");
@@ -1342,7 +1343,7 @@ fors_dfs_save_image_err_mask(cpl_frameset *frameset, const fors_image *image,
     cpl_propertylist_append_string(extension_header, 
                                    "EXTNAME", "IMAGE.BPM");
 
-    filename = cpl_calloc(strlen(category) + 6, sizeof(char));
+    filename = (char*)cpl_calloc(strlen(category) + 6, sizeof(char));
 
     strlower(strcpy(filename, category));
     strcat(filename, ".fits");
@@ -1363,8 +1364,7 @@ do { \
  * @param header        to write to
  * @param frame         get keywords from this frame
  */
-void fors_dfs_add_wcs(cpl_propertylist *header, const cpl_frame *frame,
-                      const fors_setting *setting)
+void fors_dfs_copy_wcs(cpl_propertylist *header, const cpl_frame *frame)
 {
     bool invert = false;
     int extension = 0;
@@ -1375,25 +1375,6 @@ void fors_dfs_add_wcs(cpl_propertylist *header, const cpl_frame *frame,
   
     cpl_propertylist_copy_property_regexp(header, wcs_header, ".*", invert);
 
-    double crpix1 = cpl_propertylist_get_double(header, FORS_PFITS_CRPIX1);
-
-    assure( !cpl_error_get_code(), return, 
-            "Could not read %s from %s", FORS_PFITS_CRPIX1, 
-            cpl_frame_get_filename(frame));
-            
-    double crpix2 = cpl_propertylist_get_double(header, FORS_PFITS_CRPIX2);
-
-    assure( !cpl_error_get_code(), return, 
-            "Could not read %s from %s", FORS_PFITS_CRPIX2,
-            cpl_frame_get_filename(frame));
-    
-    cpl_propertylist_update_double(header, FORS_PFITS_CRPIX1,
-                                   crpix1 - setting->prescan_x);
-    
-    cpl_propertylist_update_double(header, FORS_PFITS_CRPIX2,
-                                   crpix2 - setting->prescan_y);
-
-    
     cleanup;
     return;
 }
@@ -1534,7 +1515,7 @@ int dfs_save_image(cpl_frameset *frameset, const cpl_image *image,
 
     cpl_msg_info(func, "Saving %s image to disk...", category);
 
-    filename = cpl_calloc(strlen(category) + 6, sizeof(char));
+    filename = (char*)cpl_calloc(strlen(category) + 6, sizeof(char));
 
     strlower(strcpy(filename, category));
     strcat(filename, ".fits");
@@ -1658,7 +1639,7 @@ int dfs_save_table(cpl_frameset *frameset, const cpl_table *table,
 
     cpl_msg_info(func, "Saving %s table to disk...", category);
 
-    filename = cpl_calloc(strlen(category) + 6, sizeof(char));
+    filename = (char*)cpl_calloc(strlen(category) + 6, sizeof(char));
 
     strlower(strcpy(filename, category));
 
@@ -1882,7 +1863,7 @@ cpl_error_code dfs_save_table_ext(cpl_table        * table,
 				  const char             * tag,
 				  cpl_propertylist * extheader)
 {
-    char * filename = cpl_calloc(strlen(tag) + 6, sizeof(char));
+    char * filename = (char*)cpl_calloc(strlen(tag) + 6, sizeof(char));
     cpl_propertylist * header;
 
     if (extheader) { 
@@ -1921,7 +1902,7 @@ cpl_error_code dfs_save_image_ext(cpl_image        * image,
 				  const char             * tag,
 				  cpl_propertylist * extheader)
 {
-    char * filename = cpl_calloc(strlen(tag) + 6, sizeof(char));
+    char * filename = (char*)cpl_calloc(strlen(tag) + 6, sizeof(char));
     
     cpl_propertylist * header;
 
@@ -1967,7 +1948,7 @@ cpl_error_code dfs_save_image_null(cpl_frameset * frameset,
 				   const char * version)
 {
 
-    char * filename = cpl_calloc(strlen(tag) + 6, sizeof(char));
+    char * filename = (char*)cpl_calloc(strlen(tag) + 6, sizeof(char));
 
     cpl_error_code error;
 
