@@ -56,30 +56,31 @@ typedef enum _fors_type_ fors_type;
 #define SCIENCE_IMG             "SCIENCE_IMG"
 
 /* Pipeline products */
-#define MASTER_BIAS             "MASTER_BIAS"
-#define MASTER_DARK             "MASTER_DARK"
-#define MASTER_SCREEN_FLAT_IMG  "MASTER_SCREEN_FLAT_IMG"
-#define MASTER_NORM_FLAT_IMG    "MASTER_NORM_FLAT_IMG"
-#define MASTER_SKY_FLAT_IMG     "MASTER_SKY_FLAT_IMG"
-#define SOURCES_SCI             "SOURCES_SCI_IMG"
-#define SOURCES_STD             "SOURCES_STD_IMG"
-#define ALIGNED_PHOT            "ALIGNED_PHOT"
-#define STATIC_PHOT_COEFF_TABLE "STATIC_PHOT_COEFF_TABLE"
-#define STANDARD_REDUCED_IMG    "STANDARD_REDUCED_IMG"
-#define SCIENCE_REDUCED_IMG     "SCIENCE_REDUCED_IMG"
-#define SCIENCE_REDUCED_IMG_IDP "SCIENCE_REDUCED_IMG_IDP"
-#define SCIENCE_REDUCED_WEG_IDP "SCIENCE_REDUCED_WEIGHT_IDP"
-#define SCIENCE_REDUCED_ERR_IDP "SCIENCE_REDUCED_ERR_IDP"
-#define PHOTOMETRY_TABLE        "OBJECT_TABLE_SCI_IMG"
-#define PHOT_BACKGROUND_SCI_IMG "PHOT_BACKGROUND_SCI_IMG"
-#define PHOT_BACKGROUND_STD_IMG "PHOT_BACKGROUND_STD_IMG"
-#define CORRECTION_MAP          "CORRECTION_MAP"
-#define CORRECTION_FACTOR       "CORRECTION_FACTOR"
-#define MASTER_FLAT_IMG         "MASTER_FLAT_IMG"
-#define PHOT_COEFF_TABLE        "PHOT_COEFF_TABLE"
-#define EXTINCTION_PER_NIGHT    "EXTINCTION_PER_NIGHT"
-#define EXTINCTION_PER_FRAME    "EXTINCTION_PER_FRAME"
-#define OFFSET_HISTOGRAM        "OFFSET_HISTOGRAM"
+#define MASTER_BIAS                 "MASTER_BIAS"
+#define MASTER_DARK                 "MASTER_DARK"
+#define MASTER_SCREEN_FLAT_IMG      "MASTER_SCREEN_FLAT_IMG"
+#define MASTER_NORM_FLAT_IMG        "MASTER_NORM_FLAT_IMG"
+#define MASTER_SKY_FLAT_IMG         "MASTER_SKY_FLAT_IMG"
+#define SOURCES_SCI                 "SOURCES_SCI_IMG"
+#define SOURCES_STD                 "SOURCES_STD_IMG"
+#define ALIGNED_PHOT                "ALIGNED_PHOT"
+#define STATIC_PHOT_COEFF_TABLE     "STATIC_PHOT_COEFF_TABLE"
+#define DETECTOR_ILLUMINATED_REGION "DETECTOR_ILLUMINATED_REGION"
+#define STANDARD_REDUCED_IMG        "STANDARD_REDUCED_IMG"
+#define SCIENCE_REDUCED_IMG         "SCIENCE_REDUCED_IMG"
+#define SCIENCE_REDUCED_IMG_IDP     "SCIENCE_REDUCED_IMG_IDP"
+#define SCIENCE_REDUCED_WEG_IDP     "SCIENCE_REDUCED_WEIGHT_IDP"
+#define SCIENCE_REDUCED_ERR_IDP     "SCIENCE_REDUCED_ERR_IDP"
+#define PHOTOMETRY_TABLE            "OBJECT_TABLE_SCI_IMG"
+#define PHOT_BACKGROUND_SCI_IMG     "PHOT_BACKGROUND_SCI_IMG"
+#define PHOT_BACKGROUND_STD_IMG     "PHOT_BACKGROUND_STD_IMG"
+#define CORRECTION_MAP              "CORRECTION_MAP"
+#define CORRECTION_FACTOR           "CORRECTION_FACTOR"
+#define MASTER_FLAT_IMG             "MASTER_FLAT_IMG"
+#define PHOT_COEFF_TABLE            "PHOT_COEFF_TABLE"
+#define EXTINCTION_PER_NIGHT        "EXTINCTION_PER_NIGHT"
+#define EXTINCTION_PER_FRAME        "EXTINCTION_PER_FRAME"
+#define OFFSET_HISTOGRAM            "OFFSET_HISTOGRAM"
 
 /* Static calibration */
 #define FLX_STD_IMG             "FLX_STD_IMG"
@@ -104,8 +105,7 @@ const char *dfs_get_parameter_string_const(const cpl_parameterlist *, const char
 cpl_image *dfs_load_image(cpl_frameset *, const char *, cpl_type, int, int);
 cpl_table *dfs_load_table(cpl_frameset *, const char *, int);
 cpl_propertylist *dfs_load_header(cpl_frameset *, const char *, int);
-void fors_dfs_add_wcs(cpl_propertylist *header, const cpl_frame *frame,
-                      const fors_setting *setting);
+void fors_dfs_copy_wcs(cpl_propertylist *header, const cpl_frame *frame);
 void fors_dfs_add_exptime(cpl_propertylist *header, const cpl_frame *frame,
                           double exptime);
 void
