@@ -258,7 +258,7 @@ extract_method *
 fors_extract_method_new(                    const cpl_parameterlist *parameters,
                                             const char *context)
 {
-    extract_method *em = cpl_malloc(sizeof(*em));
+    extract_method *em = (extract_method*)cpl_malloc(sizeof(*em));
     const char *name = NULL;
     const char *method = NULL;
 
