@@ -1,3 +1,26 @@
+/*
+ * This file is part of the FORS Library
+ * Copyright (C) 2002-2010 European Southern Observatory
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "fors_img_idp.h"
 #include "fors_dfs_idp.h"
 #include "fors_utils.h"
@@ -144,40 +167,44 @@ bool try_to_use_header(const cpl_propertylist * header, double *ret){
  * @param   TRUE in case of success
  */
 bool fors_img_idp_get_image_psf_fwhm(const fors_star_list *sources,
-		const fors_setting * settings,
-		const cpl_propertylist * sci_header, double * fwhm_idp){
+        const fors_setting * settings,
+        const cpl_propertylist * sci_header,
+        double * fwhm_idp, double * fwhm_pix_idp){
 
-	fors_star_list *stars = NULL;
-	*fwhm_idp = NAN;
-	if(sci_header == NULL ||
-			sources == NULL || settings == NULL) return false;
+    fors_star_list *stars = NULL;
+    *fwhm_idp = NAN;
+    if(sci_header == NULL ||
+            sources == NULL || settings == NULL) return false;
 
-	bool enough_sources = true;
-	if(should_try_to_use_sources(sci_header))
-	{
-		stars = fors_star_list_extract(sources,
-									   fors_star_duplicate,
-									   is_usable_for_FWHM_IDP, NULL);
+    bool enough_sources = true;
+    if(should_try_to_use_sources(sci_header))
+    {
+        stars = fors_star_list_extract(sources, fors_star_duplicate,
+                is_usable_for_FWHM_IDP, NULL);
 
-		const cpl_size n_selected = fors_star_list_size(stars);
-		enough_sources = n_selected >= 5;
-		const bool use_sources = stars != NULL
-				&& enough_sources//at least 5 sources
-				&& cpl_error_get_code() == CPL_ERROR_NONE;
+        const cpl_size n_selected = fors_star_list_size(stars);
+        enough_sources = n_selected >= 5;
+        const bool use_sources = stars != NULL
+                && enough_sources//at least 5 sources
+                && cpl_error_get_code() == CPL_ERROR_NONE;
 
-		if (use_sources){
-		    	const double med = fors_star_list_median(stars, fors_star_fwhm , NULL);
-		        *fwhm_idp = med * settings->pixel_scale; //fwhm is already multiplied by binx
-		        cleanup;
-		        return !std::isnan(*fwhm_idp);
-		}
-	}
+        if (use_sources){
+            const double med = fors_star_list_median(stars, fors_star_fwhm , NULL);
+            *fwhm_idp = med * settings->pixel_scale; //fwhm is already multiplied by binx
+            *fwhm_pix_idp = med;
+            cleanup;
+            fors_star_list_delete(&stars, fors_star_delete);
+            return !std::isnan(*fwhm_idp);
+        }
+        fors_star_list_delete(&stars, fors_star_delete);
+    }
 
-	if(!enough_sources || should_try_to_use_header(sci_header)){
-		const bool header_gen_success = try_to_use_header(sci_header, fwhm_idp);
-	    cleanup;
-		return header_gen_success && !std::isnan(*fwhm_idp);
-	}
+    if(!enough_sources || should_try_to_use_header(sci_header)){
+        const bool header_gen_success = try_to_use_header(sci_header, fwhm_idp);
+        *fwhm_pix_idp = *fwhm_idp / settings->pixel_scale;
+        cleanup;
+        return header_gen_success && !std::isnan(*fwhm_idp);
+    }
 
     cleanup;
     return false;
@@ -188,7 +215,8 @@ generate_imaging_idp_converter(const cpl_frame * bias_frame,
 		const fors_idp_zp_data * phot_data, const fors_image * sci,
 		const double crder, const double ra, const double dec,
 		const double skysqdeg, const double psf_fwhm,
-		const double elliptic, const double ab_mag_lim, const double ab_mag_sat){
+		const double elliptic, const double ab_mag_lim, const double ab_mag_sat,
+                const double exptime){
 
 	cpl_propertylist * bias_plist = cpl_propertylist_load(cpl_frame_get_filename(bias_frame), 0);
 
@@ -197,7 +225,7 @@ generate_imaging_idp_converter(const cpl_frame * bias_frame,
 	fors_dfs_idp_converter * to_ret =
 					fors_generate_imaging_idp_converter(bias_plist, phot_data,
 			sci, crder, ra, dec, skysqdeg,
-			psf_fwhm, elliptic, ab_mag_lim, ab_mag_sat);
+			psf_fwhm, elliptic, ab_mag_lim, ab_mag_sat, exptime);
 
 	cpl_propertylist_delete(bias_plist);
 	return to_ret;
@@ -538,11 +566,9 @@ get_data_from_raw_science(const cpl_frame * raw_frame,
 	return success;
 }
 
-static bool convert_ra_dec(const cpl_frame * raw_science,
+static bool convert_ra_dec(const cpl_propertylist * wcs_header,
 		const cpl_image * weigth, double * ra, double * dec){
 
-	cpl_propertylist * wcs_header = cpl_propertylist_load(cpl_frame_get_filename(raw_science), 0);
-
     cpl_wcs *wcs = cpl_wcs_new_from_propertylist(wcs_header);
 
     if(wcs == NULL || cpl_error_get_code()){
@@ -576,8 +602,9 @@ static bool convert_ra_dec(const cpl_frame * raw_science,
 			center_weigth_x, center_weigth_y, *ra, *dec);
 
 	cpl_matrix_delete(from_coord);
-	cpl_propertylist_delete(wcs_header);
+	cpl_matrix_delete(to_coord);
 	cpl_array_delete(status);
+	cpl_wcs_delete(wcs);
 	return success;
 }
 
@@ -629,7 +656,7 @@ static bool get_flux_aper_in_saturation(const cpl_table * sources_selected,
 	if(!err){
 		const double flux_max = pow(2.0, 16.0) - 1 - sky_med_level - overscan;
 		*flux_aper_in_sat = cpl_polynomial_eval_1d(fit1d, flux_max, NULL);
-		cpl_msg_info(cpl_func, "ABMAGSAT: Using the fitted polynomial, given a "
+		cpl_msg_debug(cpl_func, "ABMAGSAT: Using the fitted polynomial, given a "
 				"flux max = %f (sky med level = %f), the corresponding flux "
 				"aperture = %f", flux_max, sky_med_level, *flux_aper_in_sat);
 	}
@@ -746,12 +773,12 @@ static bool calc_ab_mag_sat(const cpl_table * arg_sources,
 
 	if(success){
 		const double instr_mag_sat = -2.5 * log10(flux_aper_in_saturation);
-		cpl_msg_info(cpl_func, "ABMAGSAT: Instrument mag sat = %f", instr_mag_sat);
+		cpl_msg_debug(cpl_func, "ABMAGSAT: Instrument mag sat = %f", instr_mag_sat);
 		*res = instr_mag_sat + photo_zp + ab_vega;
 	}
 
 
-	cpl_msg_info(cpl_func, "ABMAGSAT: Flux aperture "
+	cpl_msg_debug(cpl_func, "ABMAGSAT: Flux aperture "
 			"in saturation = %f, zeropoint = %f, ab-vega = %f "
 			"gives as ABMAGSAT = %f", flux_aper_in_saturation, photo_zp, ab_vega, *res);
 
@@ -759,26 +786,20 @@ static bool calc_ab_mag_sat(const cpl_table * arg_sources,
 }
 
 static double calc_ab_mag_lim(const double zp, const double ab_mag_minus_vega, const double sigma_sky_pix,
-		const double aperture_pixels_diameter, const double aperture_correction){
+		const double fwhm_pix, const double aperture_correction){
 
 	const double zp_ab = zp + ab_mag_minus_vega;
 
-	cpl_msg_info(cpl_func, "ABMAGLIM: zeropoint = %f, correction "
+	cpl_msg_debug(cpl_func, "ABMAGLIM: zeropoint = %f, correction "
 			"ab-vega = %f, zeropoint in AB used in the calculation = %f",
 			zp, ab_mag_minus_vega, zp_ab);
 
-	const double radius = aperture_pixels_diameter / 2.0;
+	cpl_msg_debug(cpl_func, "ABMAGLIM: fwhm in pix = %f, "
+				"sigma sky in pix = %f",
+				fwhm_pix, sigma_sky_pix);
 
-	const double aperture_pixels = pow(radius, 2.0) * M_PI;
-
-	cpl_msg_info(cpl_func, "ABMAGLIM: aperture diameter = %f, "
-				"aperture radius = %f, aperture pixels = %f",
-				aperture_pixels_diameter, radius, aperture_pixels);
-
-	const double abmaglim = zp_ab - 2.5 * log10(5.0 * sigma_sky_pix * sqrt(aperture_pixels)) - aperture_correction;
-
-	cpl_msg_info(cpl_func, "ABMAGLIM: sigma_sky = %f, aperture correction = %f and "
-			"abmaglim = %f", sigma_sky_pix, aperture_correction, abmaglim);
+	//See formula in PIPE-8807
+	const double abmaglim = zp_ab - 2.5 * log10(5.0 * sigma_sky_pix * sqrt(M_PI) * fwhm_pix / 2. / sqrt(log(4.))) - aperture_correction;
 
 	return abmaglim;
 }
@@ -845,7 +866,7 @@ void fors_img_idp_save(cpl_frameset * frames, const fors_image * sci,
 
 	double ra = 0;
 	double dec = 0;
-	if(!convert_ra_dec(raw_science_frame, weight_map, &ra, &dec)){
+	if(!convert_ra_dec(qc, weight_map, &ra, &dec)){
 		cpl_msg_warning(cpl_func, "Failed to find the RA/DEC "
 				"related to the center of the CCD, "
 				"IDP products will not be saved.");
@@ -855,9 +876,8 @@ void fors_img_idp_save(cpl_frameset * frames, const fors_image * sci,
 
    const double skysqdeg = pix_scale * pix_scale * cpl_image_get_flux(weight_map);
    const double aperture_correction = 0.0; //No aperture correction is performed
-   const double aperture_pixels = 40.0; //See Sextractor config file
    const double ab_mag_lim = calc_ab_mag_lim(zp_data.zp, abmag_minus_vega, qty.sigma_sky,
-		   aperture_pixels, aperture_correction);
+		   qty.psf_fwhm_pix, aperture_correction);
    double ab_mag_sat = 0.0;
    double sky_med_level = 0.0;
 
@@ -895,7 +915,7 @@ void fors_img_idp_save(cpl_frameset * frames, const fors_image * sci,
    fors_dfs_idp_converter * converter =
 		generate_imaging_idp_converter(master_bias, &zp_data,
 				sci, crder, ra, dec, skysqdeg, qty.psf_fwhm, qty.elliptic,
-				ab_mag_lim, ab_mag_sat);
+				ab_mag_lim, ab_mag_sat, exptime);
 
 
    fors_dfs_save_image_idp(frames, sci->data, fnames.idp_image_name,
