@@ -42,6 +42,7 @@
 #include "fors_overscan.h"
 #include "fors_ccd_config.h"
 #include "fors_detmodel.h"
+#include "fors_trimm_illum.h"
 #include <fors_subtract_bias.h>
 #include "fors_bpm.h"
 #include "fors_dfs_idp.h"
@@ -59,18 +60,19 @@
 /**@{*/
 
 const char *const fors_img_science_name = "fors_img_science";
-const char *const fors_img_science_description_short = "Reduce scientific exposure";
-const char *const fors_img_science_author = "Jonas M. Larsen";
+const char *const fors_img_science_description_short = "Reduce imaging scientific exposure";
+const char *const fors_img_science_author = "ESO PPS Group";
 const char *const fors_img_science_email = PACKAGE_BUGREPORT;
 const char *const fors_img_science_description = 
 "Input files:\n"
 "  DO category:               Type:       Explanation:             			Number:\n"
-"  SCIENCE_IMG                Raw         Science image               			 1\n"
-"  MASTER_BIAS                FITS image  Master bias                 			 1\n"
-"  MASTER_SKY_FLAT_IMG        FITS image  Master sky flat field       			 1\n"
-"  PHOT_COEFF_TABLE           FITS table  Observed extinction coefficients       0+\n"
-"  EXTINCTION_PER_NIGHT       FITS table  Extinction per night      			 0+\n"
-"  STATIC_PHOT_COEFF_TABLE    FITS table  Static filters coefficients     		 0+\n"
+"  " SCIENCE_IMG"                 Raw         Science image               			 1\n"
+"  " MASTER_BIAS"                 FITS image  Master bias                 			 1\n"
+"  " MASTER_SKY_FLAT_IMG"         FITS image  Master sky flat field       			 1\n"
+"  " PHOT_COEFF_TABLE"            FITS table  Observed extinction coefficients       0+\n"
+"  " EXTINCTION_PER_NIGHT"        FITS table  Extinction per night      			 0+\n"
+"  " STATIC_PHOT_COEFF_TABLE"     FITS table  Static filters photometry coefficients 	 0+\n"
+"  " DETECTOR_ILLUMINATED_REGION" FITS table  Table with detector illuminated regions	 0+\n"
 
 "\n"
 "Output files:\n"
@@ -160,6 +162,7 @@ do { \
     cpl_frameset_delete(sci_frame); \
     cpl_frameset_delete(master_bias_frame); \
     cpl_frameset_delete(master_flat_frame); \
+    cpl_frameset_delete(illum_region_frames); \
     fors_image_delete(&sci); \
     fors_image_delete(&master_bias); \
     fors_image_delete(&master_flat); \
@@ -171,8 +174,9 @@ do { \
     cpl_free((void *)context); \
     fors_setting_delete(&setting); \
     cpl_propertylist_delete(qc); \
+    cpl_propertylist_delete(wcs_header); \
     cpl_propertylist_delete(product_header); \
-    cpl_propertylist_delete(header); \
+    cpl_propertylist_delete(sci_header); \
 } while (0)
 
 /* %%% Removed from cleanup
@@ -198,11 +202,14 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     cpl_frameset *master_flat_frame = NULL;
     fors_image *master_flat         = NULL; 
 
-
+    /* Static calibrations */
+    cpl_frameset *illum_region_frames = NULL;
+    
     /* Products */
     cpl_propertylist *qc = cpl_propertylist_new();
+    cpl_propertylist *wcs_header = cpl_propertylist_new();
     cpl_propertylist *product_header = cpl_propertylist_new();
-    cpl_propertylist *header = NULL;
+    cpl_propertylist *sci_header = NULL;
     cpl_table *phot = NULL;
     fors_extract_sky_stats sky_stats;
     cpl_image *background = NULL;
@@ -263,16 +270,35 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
             "One %s required. %" CPL_SIZE_FORMAT" found", 
             MASTER_SKY_FLAT_IMG, cpl_frameset_get_size(master_flat_frame) );
 
+    /* Find static calibrations */
+    illum_region_frames = fors_frameset_extract(frames, DETECTOR_ILLUMINATED_REGION);
+    if(cpl_frameset_get_size(illum_region_frames) == 0)
+    {
+        cpl_msg_warning(cpl_func, "Input frames do not include "
+                        DETECTOR_ILLUMINATED_REGION". Images won't be trimmed "
+                        " to illuminated region.");
+    }
+    else if(cpl_frameset_get_size(illum_region_frames) != 1)
+    {
+        cpl_msg_error(cpl_func, "At most 1 frame of type "
+                      DETECTOR_ILLUMINATED_REGION" is allowed");
+        cleanup;
+        return;
+    }
+
 
     /* Done finding frames */
 
     /* Get instrument setting */
     setting = fors_setting_new(cpl_frameset_get_position(sci_frame, 0));
-    cpl_propertylist * sci_header = 
-            cpl_propertylist_load(cpl_frame_get_filename(
-                    cpl_frameset_get_position(sci_frame, 0)), 0);
+    sci_header = cpl_propertylist_load(cpl_frame_get_filename(
+        cpl_frameset_get_position(sci_frame, 0)), 0);
+    if (sci_header == NULL) {
+        cpl_msg_error(cpl_func, "Failed to load raw header");
+        cleanup;
+        return;
+    }
     fors::fiera_config ccd_config(sci_header);    
-    cpl_propertylist_delete(sci_header);
     assure( !cpl_error_get_code(), return, "Could not get instrument setting" );
 
     /* Update RON estimation from bias */
@@ -310,7 +336,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
     double average_overscan_level = 0;
     fors_image_variance_from_detmodel(sci_raw, ccd_config, overscan_levels,
-    		&average_overscan_level);
+                                      &average_overscan_level);
     
     /*Subtract overscan */
     if(perform_preoverscan)
@@ -329,6 +355,11 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     fors_image_delete(&sci_raw);
     assure( !cpl_error_get_code(), return, "Could not trimm overscan");
 
+    /* Propagate WCS information properly */
+    fors_dfs_copy_wcs(wcs_header, cpl_frameset_get_position(sci_frame, 0));
+    if(perform_preoverscan)
+        fors_trimm_preoverscan_fix_wcs(wcs_header, ccd_config);
+
     /* Subtract bias */
     fors_subtract_bias(sci, master_bias);
     assure( !cpl_error_get_code(), return, "Could not subtract master bias");
@@ -337,6 +368,7 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
     /* Load master flat */
     master_flat =
             fors_image_load(cpl_frameset_get_position(master_flat_frame, 0));
+
     assure( !cpl_error_get_code(), return, "Could not load master flat");
     
     /* Divide by normalized flat */
@@ -349,9 +381,31 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
     /* Extract sources */
     stars = fors_extract(sci, setting, em, magsyserr,
-			 &sky_stats, &background, &sources);
+                         &sky_stats, &background, &sources);
     assure( !cpl_error_get_code(), return, "Could not extract objects");  
 
+    /* Trimm non-illuminated areas */
+    if(cpl_frameset_get_size(illum_region_frames) == 1)
+    {
+        cpl_frame * illum_region_frame = 
+            cpl_frameset_get_position(illum_region_frames, 0);
+        cpl_table * illum_region =
+            cpl_table_load(cpl_frame_get_filename(illum_region_frame), 1, 1);
+
+        /* Trimming science image. 
+         * Note that it also updates the header WCS in wcs_header */
+        bool match = fors_trimm_non_illum(sci, wcs_header, setting, illum_region);
+        /* Trimming flat field, needed to compute the weights for IDPs */
+        fors_trimm_non_illum(master_flat, NULL, setting, illum_region);
+        /* Trimming background */
+        fors_trimm_non_illum(&background, NULL, setting, illum_region);
+        if(!match)
+            cpl_msg_warning(cpl_func, "Table " DETECTOR_ILLUMINATED_REGION" does"
+                            " not contain matching detector and collimator. "
+                            "No trimming of non-illuminated regions applied");
+        cpl_table_delete(illum_region);
+    }
+
     /* QC */
     fors_qc_start_group(qc, fors_qc_dic_version, setting->instrument);
     
@@ -467,55 +521,49 @@ void fors_img_science(cpl_frameset *frames, const cpl_parameterlist *parameters)
 
 /* %%% */
 
-    header = cpl_propertylist_load(
-                        cpl_frame_get_filename(
-                           cpl_frameset_get_position(sci_frame, 0)), 0);
-
-    if (header == NULL) {
-        cpl_msg_error(cpl_func, "Failed to load raw header");
-        cleanup;
-        return;
-    }
-
-    avg_airmass = fors_get_airmass(header);
+    avg_airmass = fors_get_airmass(sci_header);
 
     cpl_propertylist_update_double(qc, "AIRMASS", avg_airmass);
     cpl_propertylist_update_double(product_header, "AIRMASS", avg_airmass);
 
 /* %%% */
 
-    fors_dfs_add_wcs(qc, cpl_frameset_get_position(sci_frame, 0), setting);
     fors_dfs_add_exptime(qc, cpl_frameset_get_position(sci_frame, 0), 0.);
-    fors_dfs_add_wcs(product_header, cpl_frameset_get_position(sci_frame, 0), 
-                     setting);
     fors_dfs_add_exptime(product_header, cpl_frameset_get_position(sci_frame, 0), 0.);
+    /* Both qc and product_header have the WCS information
+     * qc will be used for the final science frame and the IDPs.
+     * product_header is used for PHOT_BACKGROUND_SCI_IMG */ 
+    cpl_propertylist_copy_property_regexp(qc, wcs_header, ".*", false);
+    cpl_propertylist_copy_property_regexp(product_header, wcs_header, ".*", false);
 
     const cpl_frame * inherit_frame = cpl_frameset_get_position_const(sci_frame, 0);
 
     if(generate_idp){
 
-    	double image_fswm = 0;
-    	const bool fwhm_available = fors_img_idp_get_image_psf_fwhm(stars, setting, header, &image_fswm);
+        double image_fwhm = 0; //in arcsec
+        double image_fwhm_pix = 0; //in pixel
+        const bool fwhm_available = fors_img_idp_get_image_psf_fwhm(stars, setting,
+            sci_header, &image_fwhm, &image_fwhm_pix);
 
-    	if(fwhm_available){
+        if(fwhm_available){
 
-    		fors_img_idp_quality qty(image_fswm, ellipticity,
-    		    sky_stats.bkg_rms, sky_mag, average_overscan_level, sources);
+            fors_img_idp_quality qty(image_fwhm, image_fwhm_pix, ellipticity,
+                sky_stats.bkg_rms, sky_mag, average_overscan_level, sources);
 
-    		fors_img_idp_save(frames, sci, qc, parameters,
-    			inherit_frame, cpl_frameset_get_position(master_bias_frame, 0),
-				master_flat, idp_weights_threshold, IDP_Products_Filenames,
-				qty);
-    	}
-    	else{
-    		cpl_msg_warning(cpl_func, "Unable to calculate PSF_FWHM, aborting IDP generation");
-    		cpl_error_reset();
-    	}
+           fors_img_idp_save(frames, sci, qc, parameters,
+                inherit_frame, cpl_frameset_get_position(master_bias_frame, 0),
+                master_flat, idp_weights_threshold, IDP_Products_Filenames,
+                qty);
+        }
+        else{
+            cpl_msg_warning(cpl_func, "Unable to calculate PSF_FWHM, aborting IDP generation");
+            cpl_error_reset();
+        }
     }
 
     fors_dfs_save_image_err(frames, sci, SCIENCE_REDUCED_IMG,
                         qc, NULL, parameters, fors_img_science_name, 
-						inherit_frame);
+                        inherit_frame);
 
     assure( !cpl_error_get_code(), return, "Saving %s failed",
             SCIENCE_REDUCED_IMG);
