@@ -31,8 +31,8 @@ extract_flux(const cpl_image * img, const cpl_size idx){
 
 
 static const char * wave_units = "angstrom";
-static const char * flx_units = "10**(-16) erg cm**(-2) sec**(-1) angstrom**(-1)";
-static const char * flx_units_uncalib = "adu sec**(-1)";
+static const char * flx_units = "10**(-16).erg.cm**(-2).sec**(-1).angstrom**(-1)";
+static const char * flx_units_uncalib = "adu.sec**(-1)";
 
 static const char* type_wave = "spec:Data.SpectralAxis.Value";
 static const char* type_flx = "spec:Data.FluxAxis.Value";
@@ -41,10 +41,10 @@ static const char* type_flx_uncalib = "eso:Data.FluxAxis.Value";
 static const char* type_flx_err_uncalib = "eso:Data.FluxAxis.Accuracy.StatError";
 
 static const char * ucd_wave = "em.wl;obs.atmos";
-static const char * ucd_flux = "phot.ux.density;em.wl;src.net;meta.main";
-static const char * ucd_flux_err = "stat.error;phot.ux.density;meta.main";
+static const char * ucd_flux = "phot.flux.density;em.wl;src.net;meta.main";
+static const char * ucd_flux_err = "stat.error;phot.flux.density;meta.main";
 
-static const char * ucd_flux_uncalib = "phot.ux.density;em.wl;src.net;stat.uncalib";
+static const char * ucd_flux_uncalib = "phot.flux.density;em.wl;src.net;stat.uncalib";
 static const char * ucd_flux_err_uncalib = "stat.error;phot.flux.density;stat.uncalib";
 
 
@@ -241,23 +241,18 @@ has_double_property(const cpl_propertylist * plist, const char * name){
 }
 
 static bool
-add_exptimes_and_mjd(const cpl_propertylist * plist, irplib_sdp_spectrum * spec){
+add_exptimes_and_mjd(const cpl_propertylist * plist, irplib_sdp_spectrum * spec, const double exptime){
 
-	const char * win1 = "ESO DET WIN1 DIT1";
+    bool success = true;
 	const char * mjd = "MJD-OBS";
 
-	bool success = has_double_property(plist, win1) && has_double_property(plist, mjd);
-
-	if(!success) return false;
-
-	const double win1dit1 = cpl_propertylist_get_double(plist, win1);
 	const double mjd_obs = cpl_propertylist_get_double(plist, mjd);
 
 	const double sec_in_day = 86400.0;
-	const double mjd_end = mjd_obs + win1dit1 / sec_in_day;
+	const double mjd_end = mjd_obs + exptime / sec_in_day;
 
-	success = success && irplib_sdp_spectrum_set_exptime(spec, win1dit1) == CPL_ERROR_NONE;
-	success = success && irplib_sdp_spectrum_set_texptime(spec, win1dit1) == CPL_ERROR_NONE;
+	success = success && irplib_sdp_spectrum_set_exptime(spec, exptime) == CPL_ERROR_NONE;
+	success = success && irplib_sdp_spectrum_set_texptime(spec, exptime) == CPL_ERROR_NONE;
 	success = success && irplib_sdp_spectrum_set_mjdobs(spec, mjd_obs) == CPL_ERROR_NONE;
 	success = success && irplib_sdp_spectrum_set_mjdend(spec, mjd_end) == CPL_ERROR_NONE;
 	success = success && irplib_sdp_spectrum_set_telapse(spec, (mjd_end - mjd_obs) * sec_in_day) == CPL_ERROR_NONE;
@@ -276,7 +271,6 @@ add_constants(irplib_sdp_spectrum * spectrum){
 	success = success && irplib_sdp_spectrum_set_prodcatg(spectrum, "SCIENCE.SPECTRUM") == CPL_ERROR_NONE;
 	success = success && irplib_sdp_spectrum_set_voclass(spectrum, "SPECTRUM V2.0") == CPL_ERROR_NONE;
 	success = success && irplib_sdp_spectrum_set_vopub(spectrum, "ESO/SAF") == CPL_ERROR_NONE;
-	success = success && irplib_sdp_spectrum_set_title(spectrum, "OBJECT") == CPL_ERROR_NONE;
 
 	return success;
 }
@@ -540,20 +534,27 @@ add_bin(const cpl_propertylist * sci_reduced_header, irplib_sdp_spectrum * spect
 
 
 static double calc_snr(const irplib_sdp_spectrum * spectrum){
-	const cpl_array * flx = irplib_sdp_spectrum_get_column_data(spectrum, "FLUX");
-	const cpl_array * err = irplib_sdp_spectrum_get_column_data(spectrum, "ERR");
+    const cpl_array * flx = irplib_sdp_spectrum_get_column_data(spectrum, "FLUX");
+    const cpl_array * err = irplib_sdp_spectrum_get_column_data(spectrum, "ERR");
 
-	cpl_array * div = cpl_array_duplicate(flx);
-	cpl_array_divide(div, err);
-	const double ret = cpl_array_get_median(div);
-	cpl_array_delete(div);
+    cpl_array * div = cpl_array_duplicate(flx);
+    cpl_array_divide(div, err);
 
-	if(cpl_error_get_code()) {
-		cpl_error_reset();
-		return NAN;
-	}
+    int valid;
+    for(int i=0; i<cpl_array_get_size(flx); ++i)
+        if(cpl_array_get_double(flx, i, &valid)==-1 &&
+           cpl_array_get_double(err, i, &valid)==-1)
+            cpl_array_set_invalid(div, i);
 
-	return ret;
+    const double ret = cpl_array_get_median(div);
+    cpl_array_delete(div);
+
+    if(cpl_error_get_code()) {
+        cpl_error_reset();
+        return NAN;
+    }
+
+    return ret;
 }
 
 static bool add_snr(irplib_sdp_spectrum * spectrum){
@@ -563,7 +564,9 @@ static bool add_snr(irplib_sdp_spectrum * spectrum){
 	return irplib_sdp_spectrum_set_snr(spectrum, snr) == CPL_ERROR_NONE;
 }
 
-static bool add_object(const cpl_propertylist * sci_reduced_header, irplib_sdp_spectrum * spectrum){
+static bool add_object(const cpl_propertylist * sci_reduced_header, 
+                       irplib_sdp_spectrum * spectrum,
+                       cpl_size idx_spectrum){
 
 	const char * ob_tag = "OBJECT";
 	bool success = has_string_property(sci_reduced_header, ob_tag);
@@ -571,7 +574,11 @@ static bool add_object(const cpl_propertylist * sci_reduced_header, irplib_sdp_s
 	if(!success) return false;
 
 	const char * ob = cpl_propertylist_get_string(sci_reduced_header, ob_tag);
-	return irplib_sdp_spectrum_set_object(spectrum, ob) == CPL_ERROR_NONE;
+        std::stringstream oss;
+        oss<<ob<<"_"<<idx_spectrum+1;
+	success = success && irplib_sdp_spectrum_set_object(spectrum, ob) == CPL_ERROR_NONE;
+	success = success && irplib_sdp_spectrum_set_title(spectrum, oss.str().c_str()) == CPL_ERROR_NONE;
+	return success;
 }
 
 static
@@ -580,13 +587,15 @@ bool add_spectrum_metadata(irplib_sdp_spectrum * spectrum ,
 		const cpl_propertylist * sci_reduced_header,
 		const cpl_propertylist * ids_header,
 		const double ra, const double dec,
-		const double ron, const double spec_sye){
+		const double ron, const double spec_sye,
+                const double exptime,
+                cpl_size idx_spectrum){
 
 	if(sci_reduced_header == NULL || spectrum == NULL) return false;
 
 	bool success = irplib_sdp_spectrum_set_ra(spectrum, ra) == CPL_ERROR_NONE;
 	success = success && irplib_sdp_spectrum_set_dec(spectrum, dec) == CPL_ERROR_NONE;
-	success = success && add_exptimes_and_mjd(sci_reduced_header, spectrum);
+	success = success && add_exptimes_and_mjd(sci_reduced_header, spectrum, exptime);
 	success = success && add_obs(sci_reduced_header, spectrum);
 	success = success && add_constants(spectrum);
 	success = success && add_pro(sci_reduced_header, spectrum);
@@ -597,7 +606,7 @@ bool add_spectrum_metadata(irplib_sdp_spectrum * spectrum ,
 	success = success && add_qc_res(spectrum, ids_header, spec_sye);
 	success = success && add_bin(sci_reduced_header, spectrum);
 	success = success && add_snr(spectrum);
-	success = success && add_object(sci_reduced_header, spectrum);
+	success = success && add_object(sci_reduced_header, spectrum, idx_spectrum);
 
 	return success;
 }
@@ -830,7 +839,7 @@ void fors_spec_idp_save_idp_format(fors_spec_idp_save_info info, const cpl_image
 
 
 		if(!add_spectrum_metadata(spectrum, wlens, plist, plist_ids,
-				ra, dec, ron, info.spec_sye)){
+				ra, dec, ron, info.spec_sye, info.exptime, idx_spectrum)){
 			cpl_msg_warning(cpl_func, "Unable to generate IDP metadata for spectrum %lld, aborting IDP generation", idx_spectrum + 1);
 			cpl_error_reset();
 			irplib_sdp_spectrum_delete(spectrum);
