@@ -652,8 +652,10 @@ Moved outside by Carlo - end */
     cpl_propertylist_delete(qc_phot); qc_phot = NULL;
 
     /* FIXME: FAP: use WCS corrected header */
-    fors_dfs_add_wcs(product_header,
-                     cpl_frameset_get_position(std_frame, 0), setting);
+    fors_dfs_copy_wcs(product_header,
+                      cpl_frameset_get_position(std_frame, 0));
+    if(perform_preoverscan)
+        fors_trimm_preoverscan_fix_wcs(product_header, ccd_config);
     /* FIXME: FAP: use WCS corrected header */
     fors_dfs_add_exptime(product_header, 
                          cpl_frameset_get_position(std_frame, 0), 0.);
