@@ -225,7 +225,7 @@ void test_idp_science_imaging(void){
 	fors_dfs_idp_converter * conv =
 			fors_generate_imaging_idp_converter(master_bias_plist, &phot_data,
 					img, crder, ra, dec, skysqdeg, psf_fwhm,
-					elliptic, ab_mag_lim, ab_mag_sat);
+					elliptic, ab_mag_lim, ab_mag_sat, exptime);
 
 	cpl_propertylist * result =
 			fors_dfs_idp_converter_generate_idp_propertylist(conv, raw_plist);
