@@ -36,6 +36,7 @@
 
 #include <test_simulate.h>
 #include <test.h>
+#include <fs_test.h>
 
 #include <cpl.h>
 #include <math.h>
@@ -56,6 +57,10 @@ do { \
     fors_image_delete(&master_bias); \
     fors_setting_delete(&setting); \
     cpl_propertylist_delete(product_header); \
+    delete_test_files(screen_flat_filename);\
+    delete_test_file(master_name);\
+    delete_test_file_from_tag(MASTER_SCREEN_FLAT_IMG);\
+    delete_test_file_from_tag(MASTER_NORM_FLAT_IMG);\
 } while(0)
 
 /**
@@ -79,6 +84,8 @@ test_img_screen_flat(void)
     const char *screen_flat_filename[] = {"img_screen_flat_1.fits",
                                           "img_screen_flat_2.fits",
                                           "img_screen_flat_3.fits"};
+
+    const char* master_name = "img_screen_flat_master_bias.fits";
     const unsigned N =  sizeof(screen_flat_filename)/sizeof(char *);
 
     {
@@ -93,7 +100,7 @@ test_img_screen_flat(void)
     }
     
     cpl_frameset_insert(frames, 
-                        create_master_bias("img_screen_flat_master_bias.fits", 
+                        create_master_bias(master_name,
                                     MASTER_BIAS, CPL_FRAME_GROUP_CALIB));
     
     /* Define parameters */
