@@ -326,7 +326,7 @@ do { \
  */
 cpl_frame *
 create_dark(const char *filename, const char *tag,
-		cpl_frame_group group, const int number_saturated)
+            cpl_frame_group group, const int number_saturated)
 {
     int nx = det_nx / binx + pres_nx;
     int ny = det_ny / biny;
@@ -350,11 +350,11 @@ create_dark(const char *filename, const char *tag,
                         + 0.5);
 
                 if(num_sat < number_saturated && x > pres_nx){
-                	num_sat ++;
-                	if(num_sat % 2)
-                		val = 65000;
-                	else
-                		val = 0.23;
+                    num_sat ++;
+                    if(num_sat % 2)
+                        val = 65000;
+                    else
+                        val = 0.23;
                 }
 
                 cpl_image_set(data, x, y, val);
@@ -768,4 +768,60 @@ create_zeropint_header_table(const char *filename, const char *tag, cpl_frame_gr
     return frame_new(filename, tag, group);
 }
 
+#undef cleanup
+#define cleanup \
+do { \
+    cpl_table_delete(t); \
+} while(0)
+
+/**
+ * @brief   Create a table with information about illuminated regions
+ * @param   filename        save to this file
+ * @param   tag             output frame tag
+ * @param   group           output frame group
+ * @return  illuminated regions table
+ */
+cpl_frame *
+create_illum_table(const char *filename, const char *tag, cpl_frame_group group)
+{
+    cpl_table *t;
+    struct {
+        const char*  chip_id;
+        const char*  coll_name;
+        int          llx, lly, urx, ury;
+    } 
+    data[FORS_NUM_FILTER] = {
+        {"Test chip 234", "collimator name", 11, 1, 110, 150},
+        {"Test chip 123", "collimator name", 100, 100, 200, 200}
+    };
+    
+    const int N=2;
+    t = cpl_table_new(N);
+    cpl_table_new_column(t, "det_chip1_id"           , CPL_TYPE_STRING);
+    cpl_table_new_column(t, "ins_coll_name"          , CPL_TYPE_STRING);
+    cpl_table_new_column(t, "illuminated_region_llx" , CPL_TYPE_INT);
+    cpl_table_new_column(t, "illuminated_region_lly" , CPL_TYPE_INT);
+    cpl_table_new_column(t, "illuminated_region_urx" , CPL_TYPE_INT);
+    cpl_table_new_column(t, "illuminated_region_ury" , CPL_TYPE_INT);
+
+    for (int i = 0; i < N; i++) {
+        cpl_table_set_string(t, "det_chip1_id"  , i, data[i].chip_id);
+        cpl_table_set_string(t, "ins_coll_name" , i, data[i].coll_name);
+        cpl_table_set_int(t, "illuminated_region_llx" , i, data[i].llx);
+        cpl_table_set_int(t, "illuminated_region_lly" , i, data[i].lly);
+        cpl_table_set_int(t, "illuminated_region_urx" , i, data[i].urx);
+        cpl_table_set_int(t, "illuminated_region_ury" , i, data[i].ury);
+    }
+
+    cpl_table_save(t, NULL, NULL, filename, CPL_IO_DEFAULT);
+    assure( !cpl_error_get_code(), return NULL, 
+            "Failed to save photometry table to %s", filename );
+    
+    cleanup;
+    return frame_new(filename, tag, group);
+}
+
+#undef cleanup
+#define cleanup \
+
 /**@}*/
