@@ -270,6 +270,10 @@ extern int imcore_conf(casu_fits *infile, casu_fits *conf, intptr_t ipix,
     /* Work out isophotal detection threshold levels */
 
     thresh = threshold*skysig;
+    if (!bkg_subtr && thresh < skymed) {
+        FATAL_ERR("Bad background corrected input. Background estimation "
+                  "disabled but image median larger than threshold * sigma.");
+    }
     
     /* Minimum intensity for consideration */
 
