@@ -51,41 +51,23 @@
                                    Define
  -----------------------------------------------------------------------------*/
 
-/*----------------------------------------------------------------------------*/
-/**
-  @enum hdrl_imagelist_basic_type
-  @brief Define the kind of operation to apply
- */
-/*----------------------------------------------------------------------------*/
-typedef enum {
-	HDRL_IMLIST_BASIC_IMLIST = 0,
-	HDRL_IMLIST_BASIC_IMAGE,
-	HDRL_IMLIST_BASIC_SCALAR
-} hdrl_imagelist_basic_type;
+#define HDRL_IMLIST_BASIC_IMLIST    0
+#define HDRL_IMLIST_BASIC_IMAGE     1
+#define HDRL_IMLIST_BASIC_SCALAR    2
 
 /*-----------------------------------------------------------------------------
                             Static Prototypes
  -----------------------------------------------------------------------------*/
+static cpl_error_code hdrl_imagelist_collapse_interface(const
+        hdrl_imagelist *, hdrl_collapse_imagelist_to_image_t *,
+        hdrl_image **, cpl_image **, void **);
 
-static cpl_error_code hdrl_imagelist_basic_operation(
-		hdrl_imagelist_basic_type type,
-		void                      *func,
-		hdrl_imagelist            *himlist1,
-		const hdrl_imagelist      *himlist2,
-		const hdrl_image          *himg,
-		hdrl_value                *value);
-
-static cpl_error_code hdrl_imagelist_collapse_interface(
-		const hdrl_imagelist                *himlist,
-        hdrl_collapse_imagelist_to_image_t  *collapse_method,
-        hdrl_image                          **out,
-        cpl_image                           **contrib,
-        void                                **eout);
 
 /*-----------------------------------------------------------------------------
                             Function codes
  -----------------------------------------------------------------------------*/
 
+#define HDRL_OPERATION HDRL_IMLIST_BASIC_IMLIST
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Add two image lists, the first one is replaced by the result.
@@ -106,8 +88,9 @@ cpl_error_code hdrl_imagelist_add_imagelist(
         hdrl_imagelist        *    himlist1,
         const hdrl_imagelist  *    himlist2)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMLIST,
-			&hdrl_image_add_image, himlist1, himlist2, NULL, NULL);
+#define HDRL_OPERATOR hdrl_image_add_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -124,8 +107,9 @@ cpl_error_code hdrl_imagelist_sub_imagelist(
         hdrl_imagelist        *    himlist1,
         const hdrl_imagelist  *    himlist2)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMLIST,
-			&hdrl_image_sub_image, himlist1, himlist2, NULL, NULL);
+#define HDRL_OPERATOR hdrl_image_sub_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -142,8 +126,9 @@ cpl_error_code hdrl_imagelist_mul_imagelist(
         hdrl_imagelist        *    himlist1,
         const hdrl_imagelist  *    himlist2)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMLIST,
-			&hdrl_image_mul_image, himlist1, himlist2, NULL, NULL);
+#define HDRL_OPERATOR hdrl_image_mul_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -160,11 +145,13 @@ cpl_error_code hdrl_imagelist_div_imagelist(
         hdrl_imagelist        *    himlist1,
         const hdrl_imagelist  *    himlist2)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMLIST,
-			&hdrl_image_div_image, himlist1, himlist2, NULL, NULL);
+#define HDRL_OPERATOR hdrl_image_div_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
+#undef HDRL_OPERATION
 
-
+#define HDRL_OPERATION HDRL_IMLIST_BASIC_IMAGE
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Add an image to an image list.
@@ -183,8 +170,9 @@ cpl_error_code hdrl_imagelist_add_image(
         hdrl_imagelist      *    himlist,
         const hdrl_image    *    himg)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMAGE,
-			&hdrl_image_add_image, himlist, NULL, himg, NULL);
+#define HDRL_OPERATOR hdrl_image_add_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -206,8 +194,9 @@ cpl_error_code hdrl_imagelist_sub_image(
         hdrl_imagelist      *    himlist,
         const hdrl_image    *    himg)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMAGE,
-			&hdrl_image_sub_image, himlist, NULL, himg, NULL);
+#define HDRL_OPERATOR hdrl_image_sub_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -229,8 +218,9 @@ cpl_error_code hdrl_imagelist_mul_image(
         hdrl_imagelist      *    himlist,
         const hdrl_image    *    himg)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMAGE,
-			&hdrl_image_mul_image, himlist, NULL, himg, NULL);
+#define HDRL_OPERATOR hdrl_image_mul_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -252,12 +242,13 @@ cpl_error_code hdrl_imagelist_div_image(
         hdrl_imagelist      *    himlist,
         const hdrl_image    *    himg)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_IMAGE,
-			&hdrl_image_div_image, himlist, NULL, himg, NULL);
+#define HDRL_OPERATOR hdrl_image_div_image
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
+#undef HDRL_OPERATION
 
-
-
+#define HDRL_OPERATION HDRL_IMLIST_BASIC_SCALAR
 /*----------------------------------------------------------------------------*/
 /**
   @brief    Elementwise addition of a scalar to each image in the himlist
@@ -274,8 +265,9 @@ cpl_error_code hdrl_imagelist_add_scalar(
         hdrl_imagelist  *   himlist,
         hdrl_value          value)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_SCALAR,
-			&hdrl_image_add_scalar, himlist, NULL, NULL, &value);
+#define HDRL_OPERATOR hdrl_image_add_scalar
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -295,8 +287,9 @@ cpl_error_code hdrl_imagelist_sub_scalar(
         hdrl_imagelist  *   himlist,
         hdrl_value          value)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_SCALAR,
-			&hdrl_image_sub_scalar, himlist, NULL, NULL, &value);
+#define HDRL_OPERATOR hdrl_image_sub_scalar
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -316,8 +309,9 @@ cpl_error_code hdrl_imagelist_mul_scalar(
         hdrl_imagelist  *   himlist,
         hdrl_value          value)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_SCALAR,
-			&hdrl_image_mul_scalar, himlist, NULL, NULL, &value);
+#define HDRL_OPERATOR hdrl_image_mul_scalar
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
 
 /*----------------------------------------------------------------------------*/
@@ -337,10 +331,11 @@ cpl_error_code hdrl_imagelist_div_scalar(
         hdrl_imagelist  *   himlist,
         hdrl_value          value)
 {
-	return hdrl_imagelist_basic_operation(HDRL_IMLIST_BASIC_SCALAR,
-			&hdrl_image_div_scalar, himlist, NULL, NULL, &value);
+#define HDRL_OPERATOR hdrl_image_div_scalar
+#include "hdrl_imagelist_basic_body.h"
+#undef HDRL_OPERATOR
 }
-
+#undef HDRL_OPERATION
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -358,12 +353,18 @@ cpl_error_code hdrl_imagelist_pow_scalar(
         hdrl_imagelist  *   himlist,
         hdrl_value          exponent)
 {
+    cpl_size    nima ;
+    cpl_size    i ;
+
+    /* Check inputs */
     cpl_ensure_code(himlist != NULL, CPL_ERROR_NULL_INPUT);
 
-    cpl_size nima = hdrl_imagelist_get_size(himlist) ;
-    for (cpl_size i = 0 ; i<nima ; i++) {
-        cpl_ensure_code(!hdrl_image_pow_scalar(hdrl_imagelist_get(himlist, i),
-        		exponent), cpl_error_get_code());
+    nima = hdrl_imagelist_get_size(himlist) ;
+
+    for (i=0 ; i<nima ; i++) {
+        hdrl_image  *   himg = hdrl_imagelist_get(himlist, i) ;
+        cpl_ensure_code(!hdrl_image_pow_scalar(himg, exponent),
+                        cpl_error_get_code());
     }
     return CPL_ERROR_NONE;
 }
@@ -536,38 +537,33 @@ cpl_error_code hdrl_imagelist_collapse_sigclip(
     hdrl_sigclip_image_output * sigclipout;
     hdrl_collapse_imagelist_to_image_t * method =
         hdrl_collapse_imagelist_to_image_sigclip(kappa_low, kappa_high, niter);
-    hdrl_imagelist_collapse_interface(himlist, method, out, contrib, (void**)&sigclipout);
-
+    hdrl_imagelist_collapse_interface(himlist, method, out, contrib,
+                                      (void**)&sigclipout);
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
-
         hdrl_collapse_imagelist_to_image_delete(method);
-
         if (reject_low) {
             *reject_low = NULL;
         }
-
         if (reject_high) {
             *reject_high = NULL;
         }
-
         return cpl_error_get_code();
     }
 
     if (reject_low) {
         *reject_low = sigclipout->reject_low;
-    } else {
+    }
+    else {
         cpl_image_delete(sigclipout->reject_low);
     }
-
     if (reject_high) {
         *reject_high = sigclipout->reject_high;
-    } else {
+    }
+    else {
         cpl_image_delete(sigclipout->reject_high);
     }
-
     hdrl_collapse_imagelist_to_image_unwrap_eout(method, sigclipout);
     hdrl_collapse_imagelist_to_image_delete(method);
-
     return cpl_error_get_code();
 }
 
@@ -600,38 +596,33 @@ cpl_error_code hdrl_imagelist_collapse_minmax(
     hdrl_minmax_image_output * minmaxout;
     hdrl_collapse_imagelist_to_image_t * method =
         hdrl_collapse_imagelist_to_image_minmax(nlow, nhigh);
-    hdrl_imagelist_collapse_interface(himlist, method, out, contrib, (void**)&minmaxout);
-
+    hdrl_imagelist_collapse_interface(himlist, method, out, contrib,
+                                      (void**)&minmaxout);
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
-
         hdrl_collapse_imagelist_to_image_delete(method);
-
         if (reject_low) {
             *reject_low = NULL;
         }
-
         if (reject_high) {
             *reject_high = NULL;
         }
-
         return cpl_error_get_code();
     }
 
     if (reject_low) {
         *reject_low = minmaxout->reject_low;
-    } else {
+    }
+    else {
         cpl_image_delete(minmaxout->reject_low);
     }
-
     if (reject_high) {
         *reject_high = minmaxout->reject_high;
-    } else {
+    }
+    else {
         cpl_image_delete(minmaxout->reject_high);
     }
-
     hdrl_collapse_imagelist_to_image_unwrap_eout(method, minmaxout);
     hdrl_collapse_imagelist_to_image_delete(method);
-
     return cpl_error_get_code();
 }
 
@@ -657,10 +648,9 @@ static cpl_error_code hdrl_imagelist_collapse_interface(
         void                                **  eout)
 {
     cpl_error_code fail = CPL_ERROR_NONE;
-
     /* Check inputs */
     cpl_ensure_code(himlist != NULL, CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(out     != NULL, CPL_ERROR_NULL_INPUT);
+    cpl_ensure_code(out != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(contrib != NULL, CPL_ERROR_NULL_INPUT);
 
     cpl_size nz = hdrl_imagelist_get_size(himlist);
@@ -670,29 +660,26 @@ static cpl_error_code hdrl_imagelist_collapse_interface(
         return cpl_error_get_code();
     }
 
-    *out     = hdrl_image_new(nx, ny);
-    *contrib = cpl_image_new( nx, ny, CPL_TYPE_INT);
-
+    *out = hdrl_image_new(nx, ny);
+    *contrib = cpl_image_new(nx, ny, CPL_TYPE_INT);
     /* make sure we have masks else the copy into these is not threadsafe */
     cpl_image_get_bpm(*contrib);
     hdrl_image_get_mask(*out);
-
     /* create full extra output */
     if (eout) {
-        *eout = hdrl_collapse_imagelist_to_image_create_eout(
-        	collapse_method, hdrl_image_get_image(hdrl_imagelist_get(himlist, 0)));
+        *eout = hdrl_collapse_imagelist_to_image_create_eout(collapse_method,
+                     hdrl_image_get_image(hdrl_imagelist_get(himlist, 0)));
     }
 
     /* get blocks that can be processed in parallel
      * small blocksize better for cache but currently excessive malloc/free
      * prevents making it smaller */
     cpl_size blocksize = 16ul * (1ul<<20ul) / (nz * nx * sizeof(double));
-    hdrl_iter *it = hdrl_imagelist_get_iter_row_slices(himlist, blocksize, 0, HDRL_ITER_CONST);
-
+    hdrl_iter * it = hdrl_imagelist_get_iter_row_slices(himlist, blocksize, 0,
+                                                        HDRL_ITER_CONST);
     cpl_size nit = hdrl_iter_length(it);
-    hdrl_imagelist *vl[nit];
+    hdrl_imagelist * vl[nit];
     cpl_size yl[nit];
-
     {
         cpl_size i = 0;
         cpl_size y = 1;
@@ -704,9 +691,7 @@ static cpl_error_code hdrl_imagelist_collapse_interface(
             y += hdrl_imagelist_get_size_y(v);
         }
     }
-
     hdrl_iter_delete(it);
-
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
         for (cpl_size i = 0; i < nit; i++) {
             hdrl_imagelist_delete(vl[i]);
@@ -714,21 +699,16 @@ static cpl_error_code hdrl_imagelist_collapse_interface(
         return cpl_error_get_code();
     }
 
-    HDRL_OMP(omp parallel for)
+HDRL_OMP(omp parallel for)
     for (cpl_size i = 0; i < nit; i++) {
-
-        cpl_image     *out_data;
-        cpl_image     *out_errors;
-        cpl_image     *out_contrib;
-
-        cpl_imagelist *data;
-        cpl_imagelist *errors;
-
-        void *out_eout;
-
+        cpl_image * out_data ;
+        cpl_image * out_errors ;
+        cpl_image * out_contrib ;
+        cpl_imagelist * data ;
+        cpl_imagelist * errors ;
+        void * out_eout;
         hdrl_imagelist *v = vl[i];
         cpl_size y = yl[i];
-
         /* Build the Inputs Interface */
         hdrl_imagelist_to_cplwrap(v, &data, &errors);
 
@@ -736,124 +716,50 @@ static cpl_error_code hdrl_imagelist_collapse_interface(
         hdrl_collapse_imagelist_to_image_call(collapse_method, data, errors,
                                               &out_data, &out_errors,
                                               &out_contrib, &out_eout);
-
         if (cpl_error_get_code() != CPL_ERROR_NONE) {
-
             fail = cpl_error_get_code();
             cpl_imagelist_unwrap(data) ;
             cpl_imagelist_unwrap(errors) ;
             hdrl_imagelist_delete(v);
-
-        } else {
-
-        	cpl_msg_debug(cpl_func, "Collapsed block %lld to %lld", y,
-        			y + cpl_image_get_size_y(out_data) - 1);
-
-        	/* TODO make use of output image views to avoid copying */
-        	assert(hdrl_image_get_mask_const(*out));
-        	assert(cpl_image_get_bpm_const(*contrib));
-        	hdrl_image_insert(*out, out_data, out_errors, 1, y);
-        	cpl_image_copy(*contrib, out_contrib, 1, y);
-
-        	/* copy and delete slice extra out */
-        	if (out_eout) {
-        		hdrl_collapse_imagelist_to_image_move_eout(collapse_method,
-        				*eout, out_eout, y);
-        	}
-
-        	/* Destroy the Inputs Interface */
-        	cpl_image_delete(out_data);
-        	cpl_image_delete(out_errors);
-        	cpl_image_delete(out_contrib);
-        	cpl_imagelist_unwrap(data) ;
-        	cpl_imagelist_unwrap(errors) ;
-        	hdrl_imagelist_delete(v);
+            continue;
         }
+        cpl_msg_debug(cpl_func, "Collapsed block %lld to %lld", y,
+                      y + cpl_image_get_size_y(out_data) - 1);
+
+        /* TODO make use of output image views to avoid copying */
+        assert(hdrl_image_get_mask_const(*out));
+        assert(cpl_image_get_bpm_const(*contrib));
+        hdrl_image_insert(*out, out_data, out_errors, 1, y);
+        cpl_image_copy(*contrib, out_contrib, 1, y);
+        /* copy and delete slice extra out */
+        if (out_eout) {
+            hdrl_collapse_imagelist_to_image_move_eout(collapse_method,
+                                                       *eout, out_eout, y);
+        }
+
+        /* Destroy the Inputs Interface */
+        cpl_image_delete(out_data);
+        cpl_image_delete(out_errors);
+        cpl_image_delete(out_contrib);
+        cpl_imagelist_unwrap(data) ;
+        cpl_imagelist_unwrap(errors) ;
+        hdrl_imagelist_delete(v);
     }
 
     if (fail != CPL_ERROR_NONE) {
-
-        if (eout) {
-            hdrl_collapse_imagelist_to_image_delete_eout(collapse_method, *eout);
-        }
-
         hdrl_image_delete(*out);
         cpl_image_delete(*contrib);
-
+        if (eout) {
+            hdrl_collapse_imagelist_to_image_delete_eout(collapse_method,
+                                                         *eout);
+            *eout = NULL;
+        }
+        *out = NULL;
+        *contrib = NULL;
         return cpl_error_set_message(cpl_func, fail, "hdrl_imagelist_collapse failed");
     }
 
     return cpl_error_get_code();
 }
 
-/*----------------------------------------------------------------------------*/
-/**
- * @brief    Compute the elementwise power of each image in the himlist
- *
- * @param    type        type of operation
- * @param    func        ptr to operation what it need to apply
- * @param    himlist1    ptr to imagelist to be modified (not NULL).
- * @param    himlist2    ptr to imagelist to be apply over himlist1 or NULL
- * @param    himg        ptr to image     to be apply over himlist1 or NULL
- * @param    value       ptr to hvalue    to be apply over himlist1 or NULL
- *
- * @return   CPL_ERROR_NONE or the relevant the cpl_error_code on error
- *
- */
-/*----------------------------------------------------------------------------*/
-static cpl_error_code hdrl_imagelist_basic_operation(
-		hdrl_imagelist_basic_type type,
-		void                      *func,
-		hdrl_imagelist            *himlist1,
-		const hdrl_imagelist      *himlist2,
-		const hdrl_image          *himg,
-		hdrl_value                *value){
-
-    /* Check input */
-    cpl_ensure_code(func,     CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(himlist1, CPL_ERROR_NULL_INPUT);
-
-	switch (type) {
-		case HDRL_IMLIST_BASIC_IMLIST:
-		    cpl_ensure_code(himlist2, CPL_ERROR_NULL_INPUT);
-		    cpl_ensure_code(himlist1->ni == himlist2->ni,
-		    		CPL_ERROR_ILLEGAL_INPUT);
-			break;
-		case HDRL_IMLIST_BASIC_IMAGE:
-		    cpl_ensure_code(himg, CPL_ERROR_NULL_INPUT);
-			break;
-		case HDRL_IMLIST_BASIC_SCALAR:
-		    cpl_ensure_code(value, CPL_ERROR_NULL_INPUT);
-			break;
-	}
-
-	/* Define operations */
-	typedef cpl_error_code (*hdrl_op1)(hdrl_image *, const hdrl_image *);
-	typedef cpl_error_code (*hdrl_op2)(hdrl_image *, const hdrl_image *);
-	typedef cpl_error_code (*hdrl_op3)(hdrl_image *, hdrl_value);
-
-	hdrl_op1 f1 = func;
-	hdrl_op2 f2 = func;
-	hdrl_op3 f3 = func;
-
-    /* Loop and apply the operation */
-	cpl_error_code err;
-    for (cpl_size i = 0; i < himlist1->ni; i++) {
-    	switch (type) {
-    		case HDRL_IMLIST_BASIC_IMLIST:
-    			err = f1(himlist1->images[i], himlist2->images[i]);
-    			break;
-    		case HDRL_IMLIST_BASIC_IMAGE:
-    			err = f2(himlist1->images[i], himg);
-    			break;
-    		case HDRL_IMLIST_BASIC_SCALAR:
-    			err = f3(himlist1->images[i], *value);
-    			break;
-    	}
-		cpl_ensure_code(err == CPL_ERROR_NONE, err);
-    }
-
-    return CPL_ERROR_NONE;
-}
-
 /**@}*/
