@@ -55,8 +55,8 @@ static cpl_error_code
 hdrl_test_add(void)
 {
     {
-        hdrl_data_t a, b;
-        hdrl_error_t ea, eb;
+        hdrl_data_t a = 0., b = 0.;
+        hdrl_error_t ea = 0., eb = 0.;
         hdrl_elemop_add(&a, &ea, 1, &b, &eb, 2, NULL);
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     }
@@ -162,8 +162,8 @@ static cpl_error_code
 hdrl_test_sub(void)
 {
     {
-        hdrl_data_t a, b;
-        hdrl_error_t ea, eb;
+        hdrl_data_t a = 0., b = 0.;
+        hdrl_error_t ea = 0., eb = 0.;
         hdrl_elemop_sub(&a, &ea, 1, &b, &eb, 2, NULL);
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     }
@@ -253,8 +253,8 @@ static cpl_error_code
 hdrl_test_mul(void)
 {
     {
-        hdrl_data_t a, b;
-        hdrl_error_t ea, eb;
+        hdrl_data_t a = 0., b = 0.;
+        hdrl_error_t ea = 0., eb = 0.;
         hdrl_elemop_mul(&a, &ea, 1, &b, &eb, 2, NULL);
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     }
@@ -365,8 +365,8 @@ static cpl_error_code
 hdrl_test_div(void)
 {
     {
-        hdrl_data_t a, b;
-        hdrl_error_t ea, eb;
+        hdrl_data_t a = 0., b = 0.;
+        hdrl_error_t ea = 0., eb = 0.;
         hdrl_elemop_div(&a, &ea, 1, &b, &eb, 2, NULL);
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     }
@@ -474,8 +474,8 @@ static cpl_error_code
 hdrl_test_pow(void)
 {
     {
-        hdrl_data_t a, b;
-        hdrl_error_t ea, eb;
+        hdrl_data_t a = 0., b = 0.;
+        hdrl_error_t ea = 0., eb = 0.;
         hdrl_elemop_pow(&a, &ea, 1, &b, &eb, 2, NULL);
         cpl_test_error(CPL_ERROR_ILLEGAL_INPUT);
     }
