@@ -820,6 +820,9 @@ static int fors_detect_spectra(cpl_parameterlist *parlist,
         }
         else {
             slit_ident = 0;
+            cpl_parameter * par = cpl_parameterlist_find(parlist, "fors.fors_detect_spectra.slit_ident");
+            if(par)
+            	cpl_parameter_set_bool(par, CPL_FALSE);
             cpl_msg_info(recipe, "Global distortion model cannot be computed");
             if (cpl_error_get_code() != CPL_ERROR_NONE) {
                 fors_detect_spectra_exit(NULL);
