@@ -76,7 +76,7 @@ static char fors_extract_slits_description[] =
 
 #define fors_extract_slits_exit(message)      \
 {                                             \
-if (message) cpl_msg_error(recipe, message);  \
+if ((const char *)message != NULL) cpl_msg_error(recipe, message);  \
 cpl_image_delete(spectra);                    \
 cpl_image_delete(spatial);                    \
 cpl_table_delete(grism_table);                \
@@ -90,7 +90,7 @@ return -1;                                    \
 
 #define fors_extract_slits_exit_memcheck(message)  \
 {                                               \
-if (message) cpl_msg_info(recipe, message);     \
+if ((const char *)message != NULL) cpl_msg_info(recipe, message);     \
 printf("free spectra (%p)\n", spectra);         \
 cpl_image_delete(spectra);                      \
 printf("free spatial (%p)\n", spatial);         \
