@@ -333,13 +333,9 @@ static int fors_subtract_sky(cpl_parameterlist *parlist,
     const char *unmapped_sky_tag;
     int         nframes;
     int         rebin;
-    int         nslits;
     int         treat_as_lss;
-    int         i;
     double      reference;
     double      gain;
-    double     *xpos;
-    double      mxpos;
     int         mxu, mos, lss;
     int         rec_scib;
     int         rec_stdb;
