@@ -1,4 +1,6 @@
 # import the needed modules
+from __future__ import absolute_import
+from __future__ import print_function
 try:
   import matplotlib.gridspec
   import reflex
@@ -78,11 +80,11 @@ try:
       for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'MASTER_NORM_FLAT_'+inst_mode in frames :
           flat_norm = frames['MASTER_NORM_FLAT_'+inst_mode]
-          self.flat_norm  = PlotableNormFlat(flat_norm, curv_frame)
+          self.flat_norm  = PlotableNormSpecFlat(flat_norm, curv_frame)
                   
       for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'SCREEN_FLAT_'+inst_mode in frames :
-          self.flat_mscreen  = PlotableRawFlat(frames['SCREEN_FLAT_'+inst_mode],
+          self.flat_mscreen  = PlotableRawSpecFlat(frames['SCREEN_FLAT_'+inst_mode],
                                                flat_norm, curv_frame)
 
       #Update the parameters
@@ -324,7 +326,7 @@ the dispersion relation there will be extrapolated."""
       paramList.append(reflex.RecipeParameter('fors_calib','dispersion',group='wave calib / distorsions',description='Expected spectral dispersion (Angstrom/pixel)'))
       paramList.append(reflex.RecipeParameter('fors_calib','peakdetection',group='wave calib / distorsions',description='Initial peak detection threshold (ADU)'))
       paramList.append(reflex.RecipeParameter('fors_calib','ignore_lines',group='wave calib / distorsions',description='Catalog lines nearest to wavelengths in this list will be ignored for wavelength calibration')) 
-      paramList.append(reflex.RecipeParameter('fors_calib','used_linesets',group='wave calib / distorsions',description='Linesets to use. Valid are standard and extended (see column LINE_SET in the line catalogue)')) 
+      paramList.append(reflex.RecipeParameter('fors_calib','used_linesets',group='wave calib / distorsions',description='Linesets to use. Valid linesets are standard and extended (see column LINE_SET in the line catalogue). If you want both linesets, set the paramater to standard,extended')) 
       return paramList
 
     def setWindowHelp(self):
@@ -341,7 +343,7 @@ In this window, the user will interact with the Fors calibration (flat, slit tra
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
 
 #This is the 'main' function
 if __name__ == '__main__':
